==> gs2-java-cdk-1.0.48-sources.jar: io/gs2/cdk/lottery/ref/NamespaceRef.java <==
/*
 * Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package io.gs2.cdk.lottery.ref;

import io.gs2.cdk.core.func.GetAttr;
import io.gs2.cdk.core.func.Join;
import io.gs2.cdk.lottery.ref.PrizeTableRef;
import io.gs2.cdk.lottery.ref.LotteryModelRef;
import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

public class NamespaceRef {
    private String namespaceName;

    public NamespaceRef(
        String namespaceName
    ) {
        this.namespaceName = namespaceName;
    }

    public PrizeTableRef prizeTable(
        String prizeTableName
    ) {
        return (new PrizeTableRef(
            this.namespaceName,
            prizeTableName
        ));
    }

    public LotteryModelRef lotteryModel(
        String lotteryName
    ) {
        return (new LotteryModelRef(
            this.namespaceName,
            lotteryName
        ));
    }

    public String grn(
    ) {
        return (new Join(
            ":",
            Arrays.asList(
                "grn",
                "gs2",
                GetAttr.region(
                ).str(
                ),
                GetAttr.ownerId(
                ).str(
                ),
                "lottery",
                this.namespaceName
            )
        )).str(
        );
    }
}

==> gs2-java-cdk-1.0.58-sources.jar: io/gs2/cdk/lottery/ref/NamespaceRef.java <==
/*
 * Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package io.gs2.cdk.lottery.ref;

import io.gs2.cdk.core.func.GetAttr;
import io.gs2.cdk.core.func.Join;
import io.gs2.cdk.lottery.ref.PrizeTableRef;
import io.gs2.cdk.lottery.ref.LotteryModelRef;
import io.gs2.cdk.lottery.stampSheet.ResetBoxByUserId;
import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

public class NamespaceRef {
    private String namespaceName;

    public NamespaceRef(
        String namespaceName
    ) {
        this.namespaceName = namespaceName;
    }

    public PrizeTableRef prizeTable(
        String prizeTableName
    ) {
        return (new PrizeTableRef(
            this.namespaceName,
            prizeTableName
        ));
    }

    public LotteryModelRef lotteryModel(
        String lotteryName
    ) {
        return (new LotteryModelRef(
            this.namespaceName,
            lotteryName
        ));
    }

    public ResetBoxByUserId resetBox(
        String prizeTableName,
        String userId
    ) {
        return (new ResetBoxByUserId(
            this.namespaceName,
            prizeTableName,
            userId
        ));
    }


    public ResetBoxByUserId resetBox(
        String prizeTableName
    ) {
        return (new ResetBoxByUserId(
            this.namespaceName,
            prizeTableName,
            "#{userId}"
        ));
    }

    public String grn(
    ) {
        return (new Join(
            ":",
            Arrays.asList(
                "grn",
                "gs2",
                GetAttr.region(
                ).str(
                ),
                GetAttr.ownerId(
                ).str(
                ),
                "lottery",
                this.namespaceName
            )
        )).str(
        );
    }
}
